@tailwind base;
@tailwind components;
@tailwind utilities;

html {
  background: #0a0a0a;
  scroll-behavior: smooth;
}

@keyframes blink {
  0%, 100% { opacity: 1; }
  50% { opacity: 0; }
}

.animate-blink {
  animation: blink 1s step-end infinite;
}
