import type { Config } from "tailwindcss";

const config: Config = {
  content: [
    "./app/**/*.{ts,tsx}",
    "./components/**/*.{ts,tsx}",
  ],
  theme: {
    extend: {
      colors: {
        surface: "#111111",
        border: "#1E1E1E",
        "text-primary": "#EDEDED",
        "text-secondary": "#888888",
        destructive: "#FF4040",
        safe: "#22C55E",
      },
      fontFamily: {
        sans: ["var(--font-geist-sans)"],
        mono: ["var(--font-geist-mono)"],
      },
      maxWidth: {
        content: "800px",
      },
    },
  },
  plugins: [],
};

export default config;
